"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var graphql_1 = require("graphql");
var OperationStore = (function () {
    function OperationStore(schema) {
        this.schema = schema;
        this.storedOperations = new Map();
    }
    OperationStore.prototype.put = function (operation) {
        function isOperationDefinition(definition) {
            return definition.kind === graphql_1.Kind.OPERATION_DEFINITION;
        }
        function isString(definition) {
            return typeof definition === 'string';
        }
        var ast = isString(operation) ? graphql_1.parse(operation) : operation;
        var definitions = ast.definitions.filter(isOperationDefinition);
        if (definitions.length === 0) {
            throw new Error('OperationDefinitionNode must contain at least one definition');
        }
        if (definitions.length > 1) {
            throw new Error('OperationDefinitionNode must contain only one definition');
        }
        var validationErrors = graphql_1.validate(this.schema, ast);
        if (validationErrors.length > 0) {
            var messages = validationErrors.map(function (e) { return e.message; });
            var e = new Error("Validation Errors:\n" + messages.join('\n'));
            e['originalErrors'] = validationErrors;
            throw e;
        }
        this.storedOperations.set(definitions[0].name.value, ast);
    };
    OperationStore.prototype.get = function (operationName) {
        return this.storedOperations.get(operationName);
    };
    OperationStore.prototype.delete = function (operationName) {
        return this.storedOperations.delete(operationName);
    };
    OperationStore.prototype.getMap = function () {
        return this.storedOperations;
    };
    return OperationStore;
}());
exports.OperationStore = OperationStore;
//# sourceMappingURL=operationStore.js.map